@@ -12,7 +12,8 @@ class IgniterConfig(object):
             make_model=None,
             make_evaluator=None,
             make_trainer=None,
-            inference_spec=None
+            inference_spec=None,
+            **igniter_args
     ):
         self.model_args = model_args
         self.train_args = train_args
@@ -20,7 +21,8 @@ class IgniterConfig(object):
         self.description = description or "Experiment CLI"
         self.train_inputs = train_inputs or {}
         self.eval_inputs = eval_inputs or {}
-        self.make_model=make_model
-        self.make_evaluator=make_evaluator
-        self.make_trainer=make_trainer
-        self.inference_spec=inference_spec
+        self.make_model = make_model
+        self.make_evaluator = make_evaluator
+        self.make_trainer = make_trainer
+        self.inference_spec = inference_spec
+        self.igniter_args = igniter_args
