@@ -1,5 +1,7 @@
 from aws_sagemaker_remote.training.main import sagemaker_training_main
 from .args import train_args
+import argparse
+import torch
 
 
 def igniter_main(main, training_args=None, **sagemaker_args):
@@ -24,8 +26,18 @@ def igniter_main(main, training_args=None, **sagemaker_args):
         train_args(parser=parser, **training_args)
         if argparse_callback_input:
             argparse_callback_input(parser)
+
+    def _main(args):
+        vargs = vars(args)
+        if not vargs.get('device', None):
+            vargs['device'] = "cpu" if not torch.cuda.is_available() else "cuda"
+        args = argparse.Namespace(**vargs)
+        main(args)
+    if not sagemaker_args.get('script', None):
+        sagemaker_args['script'] = main
     sagemaker_args['argparse_callback'] = argparse_callback
     return sagemaker_training_main(
-        main=main,
+        main=_main,
+        # todo fix
         **sagemaker_args
     )
